﻿//!<#@ template language="C#" #>
//!<#@ samplevars Processor="DirectiveProcessor" #>
//!<# if (Params.Hosting != HostingEnvironment.NetCore) return string.Empty; #>
using Microsoft.Extensions.Configuration;
using Microsoft.AspNetCore.Hosting;
using System;
using System.IO;
using System.Threading.Tasks;

//!<# if (Params.DeltaV) { #>
using ITHit.WebDAV.Server.DeltaV;
//!<# } #>
//!<# if (Params.Storage == StorageType.Ntfs) { #>
using ITHit.WebDav.Server.SampleModel.ExtendedAttributes;
//!<# } #>
namespace ITHit.WebDav.Server.SampleModel.__NetCore__.Options
{
    /// <summary>
    /// Represents WebDAV Context configuration options.
    /// </summary>
    public class DavContextOptions
    {
        //!<# if (Params.Storage == StorageType.Ntfs) { #>
        /// <summary>
        /// Files and folders in this folder become available via WebDAV.
        /// </summary>
        public string RepositoryPath { get; set; }
        //!<# } #>
        //!<# if (Params.Storage == StorageType.Db) { #>
        /// <summary>
        /// Database conntion string.
        /// </summary>
        public string ConnectionString { get; set; }
        //!<# } #>
        //!<# if (Params.DeltaV) { #>
        public AutoVersion AutoVersionMode { get; set; }
        //!<# } #>
    }

    /// <summary>
    /// Binds, validates and normalizes WebDAV Context configuration options.
    /// </summary>
    public static class DavContextOptionsValidator
    {
        /// <summary>
        /// Binds, validates and normalizes WebDAV Context configuration options.
        /// </summary>
        /// <param name="configurationSection">Instance of <see cref="IConfigurationSection"/>.</param>
        /// <param name="options">WebDAV Context configuration options.</param>
        /// <param name="env">Instance of <see cref="IHostingEnvironment"/>.</param>
        public static async Task ReadOptionsAsync(this IConfigurationSection configurationSection, DavContextOptions options, IHostingEnvironment env)
        {
            if (configurationSection == null)
            {
                throw new ArgumentNullException("configurationSection");
            }

            configurationSection.Bind(options);

            //!<# if (Params.Storage == StorageType.Ntfs) { #>
            if (string.IsNullOrEmpty(options.RepositoryPath))
            {
                throw new ArgumentNullException("DavContextOptions.RepositoryPath");
            }

            if (!Path.IsPathRooted(options.RepositoryPath))
            {
                options.RepositoryPath = Path.GetFullPath(Path.Combine(env.ContentRootPath, options.RepositoryPath));
            }

            if (!Directory.Exists(options.RepositoryPath))
            {
                throw new DirectoryNotFoundException(string.Format("DavContextOptions.RepositoryPath specified in appsettings.webdav.json is invalid: '{0}'.", options.RepositoryPath));
            }

            if (!await new DirectoryInfo(options.RepositoryPath).IsExtendedAttributesSupportedAsync())
            {
                throw new NotSupportedException(string.Format("File system at '{0}' doesn't support extended attributes. This sample requires NTFS Alternate Data Streams support if running on Windows or extended attributes support if running on OS X or Linux.", options.RepositoryPath));
            }
            //!<# } #>
            //!<# if (Params.Storage == StorageType.Db) { #>
            if (string.IsNullOrEmpty(options.ConnectionString))
            {
                throw new ArgumentNullException("DavContextOptions.ConnectionString");
            }
            //!<# } #>
        }
    }
}
